@@ -195,9 +195,17 @@ def get_yields(element):
     such as "4 dozen cookies", returning "4 dozen" instead of "4 servings". Additionally
     accommodates yields specified in batches (e.g., "2 batches of brownies"), returning the yield as stated.
     :param element: Should be BeautifulSoup.TAG, in some cases not feasible and will then be text.
-    :return: The number of servings or items.
     :return: The number of servings, items, dozen, batches, etc...
     """
+
+    def format_count_label(count, singular, plural):
+        formatted = (
+            f"{count:.0f}"
+            if isinstance(count, float) and count.is_integer()
+            else str(count)
+        )
+        return f"{formatted} {singular if count == 1 else plural}"
+
     if element is None:
         raise ElementNotFoundInHtml(element)
     if isinstance(element, str):
@@ -210,9 +218,13 @@ def get_yields(element):
     if SERVE_REGEX_TO.search(serve_text):
         serve_text = serve_text.split(SERVE_REGEX_TO.split(serve_text, 2)[1], 2)[1]
 
-    matched = SERVE_REGEX_NUMBER.search(serve_text).groupdict().get("items") or 0
-    serve_text_lower = serve_text.lower()
+    matched_raw = SERVE_REGEX_NUMBER.search(serve_text).groupdict().get("items") or "0"
+    try:
+        matched = float(matched_raw)
+    except ValueError:
+        matched = 0.0
 
+    serve_text_lower = serve_text.lower()
     best_match = None
     best_match_length = 0
 
@@ -223,16 +235,16 @@ def get_yields(element):
             )
             if match_length > best_match_length:
                 best_match_length = match_length
-                best_match = f"{matched} {singular if int(matched) == 1 else plural}"
+                best_match = format_count_label(matched, singular, plural)
 
     if best_match:
         return best_match
 
-    plural = "s" if float(matched) > 1 or float(matched) == 0 else ""
+    plural = "s" if matched != 1 else ""
     if SERVE_REGEX_ITEMS.search(serve_text) is not None:
-        return f"{matched} item{plural}"
+        return format_count_label(matched, "item", f"item{plural}")
 
-    return f"{matched} serving{plural}"
+    return format_count_label(matched, "serving", f"serving{plural}")
 
 
 def get_equipment(equipment_items):
@@ -240,23 +252,34 @@ def get_equipment(equipment_items):
     return list(dict.fromkeys(equipment_items))
 
 
-def normalize_string(string):
-    # Convert all named and numeric character references (e.g. &gt;, &#62;)
-    unescaped_string = html.unescape(string)
-    # Remove HTML tags
-    no_html_string = re.sub("<[^>]*>", "", unescaped_string)
-    return re.sub(
-        r"\s+",
-        " ",
+def normalize_string(string: str) -> str:
+    prev = None
+    unescaped = string
+    while prev != unescaped:
+        prev = unescaped
+        unescaped = html.unescape(unescaped)
+
+    no_html_string = re.sub(r"<[^>]*>", "", unescaped)
+
+    cleaned = (
         no_html_string.replace("\xc2\xa0", " ")
         .replace("\xa0", " ")
         .replace("\u200b", "")
         .replace("\r\n", " ")
-        .replace("\n", " ")  # &nbsp;
+        .replace("\n", " ")
         .replace("\t", " ")
-        .strip(),
+        .replace("u0026#039;", "'")
+        .strip()
     )
 
+    # Only replace '((' and '))' if both are present in the string
+    if "((" in cleaned and "))" in cleaned:
+        cleaned = cleaned.replace("((", "(").replace("))", ")")
+
+    cleaned = re.sub(r"\s+", " ", cleaned)
+
+    return cleaned.strip()
+
 
 def csv_to_tags(csv, lowercase=False):
     raw_tags = csv.split(",")
