@@ -1,4 +1,3 @@
-# mypy: disallow_untyped_defs=False
 from ._abstract import AbstractScraper
 from ._grouping_utils import group_ingredients
 
@@ -8,6 +7,9 @@ class ArchanasKitchen(AbstractScraper):
     def host(cls):
         return "archanaskitchen.com"
 
+    def site_name(self):
+        return self.opengraph.site_name()
+
     def ingredient_groups(self):
         return group_ingredients(
             self.ingredients(),
