@@ -1,6 +1,5 @@
-# mypy: allow-untyped-defs
-
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 from ._grouping_utils import group_ingredients
 
 
@@ -9,6 +8,9 @@ class CookTalk(AbstractScraper):
     def host(cls):
         return "cook-talk.com"
 
+    def site_name(self):
+        raise StaticValueException(return_value="Cook-Talk")
+
     def author(self):
         author_element = self.soup.find("div", {"class": "article-content"}).find(
             "a", {"href": lambda x: x and "recipe_author" in x}
