@@ -1,8 +1,8 @@
 from ._abstract import AbstractScraper
-from ._utils import get_equipment
+from ._wprm import WPRMMixin
 
 
-class CulinaryHill(AbstractScraper):
+class CulinaryHill(WPRMMixin, AbstractScraper):
     @classmethod
     def host(cls):
         return "culinaryhill.com"
@@ -14,11 +14,3 @@ class CulinaryHill(AbstractScraper):
                 "ul.wprm-recipe-ingredients > li.wprm-recipe-ingredient"
             )
         ]
-
-    def equipment(self):
-        equipment_items = [
-            text
-            for equip in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
-            if (text := equip.get_text())
-        ]
-        return get_equipment(equipment_items)
