@@ -1,9 +1,9 @@
 from ._abstract import AbstractScraper
+from ._wprm import WPRMMixin
 from ._grouping_utils import group_ingredients
-from ._utils import get_equipment
 
 
-class FortyAprons(AbstractScraper):
+class FortyAprons(WPRMMixin, AbstractScraper):
     @classmethod
     def host(cls):
         return "40aprons.com"
@@ -53,14 +53,6 @@ class FortyAprons(AbstractScraper):
     def ratings_count(self):
         return self.schema.ratings_count()
 
-    def equipment(self):
-        equipment_items = [
-            text
-            for equip in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
-            if (text := equip.get_text())
-        ]
-        return get_equipment(equipment_items)
-
     def keywords(self):
         return self.schema.keywords()
 
