@@ -1,4 +1,3 @@
-# mypy: disallow_untyped_defs=False
 from ._abstract import AbstractScraper
 
 
@@ -6,3 +5,6 @@ class G750g(AbstractScraper):
     @classmethod
     def host(cls):
         return "750g.com"
+
+    def site_name(self):
+        return self.opengraph.site_name()
