@@ -1,8 +1,8 @@
 from ._abstract import AbstractScraper
-from ._utils import get_equipment
+from ._wprm import WPRMMixin
 
 
-class HowToFeedALoon(AbstractScraper):
+class HowToFeedALoon(WPRMMixin, AbstractScraper):
     @classmethod
     def host(cls):
         return "howtofeedaloon.com"
@@ -26,11 +26,3 @@ class HowToFeedALoon(AbstractScraper):
             ingredients_list.append(ingredient)
 
         return ingredients_list
-
-    def equipment(self):
-        equipment_items = [
-            text
-            for equip in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
-            if (text := equip.get_text())
-        ]
-        return get_equipment(equipment_items)
