@@ -50,7 +50,7 @@ class JulieGoodwin(AbstractScraper):
     def image(self):
         container = self.soup.find("div", {"class": "inner-wrap"})
         if container:
-            image = container.findNext("img", {"src": True})
+            image = container.find_next("img", {"src": True})
             return image["src"] if image else None
 
     def ingredients(self):
@@ -58,12 +58,12 @@ class JulieGoodwin(AbstractScraper):
         if ingredients:
             return [
                 normalize_string(ingredient.get_text())
-                for ingredient in ingredients.findAll("li")
+                for ingredient in ingredients.find_all("li")
             ]
 
         ingredients_heading = self.soup.find(string="Ingredients")
         if ingredients_heading:
-            ingredients = ingredients_heading.findNext("h5")
+            ingredients = ingredients_heading.find_next("h5")
             return [
                 normalize_string(ingredient.split("•", 1)[1])
                 for ingredient in ingredients.get_text().split("\n")
@@ -72,7 +72,7 @@ class JulieGoodwin(AbstractScraper):
         raise ElementNotFoundInHtml("Could not find ingredients.")
 
     def instructions(self):
-        instructions = self.soup.findAll(string=re.compile("STEP "))
+        instructions = self.soup.find_all(string=re.compile("STEP "))
         if instructions:
             return "\n".join(
                 [
