@@ -8,7 +8,7 @@ class KennyMcGovern(AbstractScraper):
         return "kennymcgovern.com"
 
     def instructions(self):
-        instructions = self.soup.findAll(
+        instructions = self.soup.find_all(
             "div", {"class": "wprm-recipe-instruction-text"}
         )
 
