@@ -1,8 +1,9 @@
 from ._abstract import AbstractScraper
-from ._utils import get_yields, get_equipment
+from ._wprm import WPRMMixin
+from ._utils import get_yields
 
 
-class MadameCuisine(AbstractScraper):
+class MadameCuisine(WPRMMixin, AbstractScraper):
     @classmethod
     def host(cls):
         return "madamecuisine.de"
@@ -58,11 +59,3 @@ class MadameCuisine(AbstractScraper):
 
     def description(self):
         return self.soup.find("div", {"class": "wprm-recipe-summary"}).get_text()
-
-    def equipment(self):
-        equipment_items = [
-            text
-            for equip in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
-            if (text := equip.get_text())
-        ]
-        return get_equipment(equipment_items)
