@@ -28,12 +28,12 @@ class PaniniHappy(AbstractScraper):
                 return img_tag["src"]
 
     def ingredients(self):
-        ingredients = self.soup.findAll("li", {"class": "ingredient"})
+        ingredients = self.soup.find_all("li", {"class": "ingredient"})
 
         return [normalize_string(ingredient.get_text()) for ingredient in ingredients]
 
     def instructions(self):
-        instructions = self.soup.findAll("li", {"class": "instruction"})
+        instructions = self.soup.find_all("li", {"class": "instruction"})
 
         return "\n".join(
             [normalize_string(instruction.get_text()) for instruction in instructions]
