@@ -7,7 +7,7 @@ class PingoDoce(AbstractScraper):
         return "pingodoce.pt"
 
     def instructions(self):
-        instructions = self.soup.findAll("div", {"class": "step-description"})
+        instructions = self.soup.find_all("div", {"class": "step-description"})
         return "\n".join([i.get_text() for i in instructions])
 
     def category(self):
