@@ -9,9 +9,7 @@ class ReceptyPreVas(AbstractScraper):
 
     def description(self):
         description = []
-        p_list = self.soup.find("div", {"class": "single-content-self"}).findChildren(
-            "p"
-        )
+        p_list = self.soup.find("div", {"class": "single-content-self"}).find_all("p")
         for p in p_list:
             text = p.get_text().strip()
             if text:
@@ -22,7 +20,7 @@ class ReceptyPreVas(AbstractScraper):
         results = {}
         ingredients_div = self.soup.find("table", {"class": "ingredients-table"})
         purpose = None
-        for row in ingredients_div.findChildren("tr"):
+        for row in ingredients_div.find_all("tr"):
             if row.find("div", {"class": "ingredient-heading"}):
                 purpose = row.get_text().strip()
                 results[purpose] = IngredientGroup([], purpose=purpose)
