@@ -1,6 +1,5 @@
-# mypy: allow-untyped-defs
-
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 
 
 class Ricetta(AbstractScraper):
@@ -8,6 +7,9 @@ class Ricetta(AbstractScraper):
     def host(cls):
         return "ricetta.it"
 
+    def site_name(self):
+        raise StaticValueException(return_value="Ricetta.it")
+
     def instructions(self):
         instructions_list = []
 
