@@ -1,8 +1,8 @@
 from ._abstract import AbstractScraper
-from ._utils import get_equipment
+from ._wprm import WPRMMixin
 
 
-class SavvySavingCouple(AbstractScraper):
+class SavvySavingCouple(WPRMMixin, AbstractScraper):
     @classmethod
     def host(cls):
         return "savvysavingcouple.net"
@@ -12,11 +12,3 @@ class SavvySavingCouple(AbstractScraper):
             "div", {"class": "wprm-recipe-instruction-text"}
         )
         return "\n".join([instruction.get_text() for instruction in instructions])
-
-    def equipment(self):
-        equipment_items = [
-            text
-            for equip in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
-            if (text := equip.get_text())
-        ]
-        return get_equipment(equipment_items)
