@@ -1,4 +1,5 @@
 from recipe_scrapers.plugins import (
+    BestImagePlugin,
     ExceptionHandlingPlugin,
     HTMLTagStripperPlugin,
     NormalizeStringPlugin,
@@ -13,6 +14,7 @@ from recipe_scrapers.plugins import (
 # Check recipe_scrapers.settings.template.py for ways to extend.
 PLUGINS = (
     ExceptionHandlingPlugin,
+    BestImagePlugin,
     StaticValueExceptionHandlingPlugin,
     HTMLTagStripperPlugin,
     NormalizeStringPlugin,
@@ -21,6 +23,8 @@ PLUGINS = (
     SchemaOrgFillPlugin,
 )
 
+BEST_IMAGE_SELECTION = True
+
 SUPPRESS_EXCEPTIONS = False
 # Applicable only if SUPPRESS_EXCEPTIONS is True, otherwise ignored
 # silence <anyScraper>.[method]() exception and return the value
