@@ -10,12 +10,12 @@ class SimplyRecipes(AbstractScraper):
     def instructions(self):
         steps = self.soup.find(
             "div", {"class": "structured-project__steps"}
-        ).ol.findAll("li")
+        ).ol.find_all("li")
 
         return "\n".join(
             [
                 normalize_string(
-                    step.div.text + "".join([p.text for p in step.findAll("p")])
+                    step.div.text + "".join([p.text for p in step.find_all("p")])
                 )
                 for step in steps
             ]
