@@ -1,20 +1,12 @@
 from ._abstract import AbstractScraper
-from ._utils import get_equipment
+from ._wprm import WPRMMixin
 
 
-class ThePlantBasedSchool(AbstractScraper):
+class ThePlantBasedSchool(WPRMMixin, AbstractScraper):
     @classmethod
     def host(cls):
         return "theplantbasedschool.com"
 
-    def equipment(self):
-        equipment_items = [
-            text
-            for equip in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
-            if (text := equip.get_text())
-        ]
-        return get_equipment(equipment_items)
-
     def instructions(self):
         return "\n".join(
             span.get_text()
