@@ -9,9 +9,7 @@ class UitPaulinesKeukenNL(AbstractScraper):
         return "uitpaulineskeuken.nl"
 
     def ingredients(self):
-        ingredients = self.soup.find("section", {"id": "ingredienten"}).findChildren(
-            "li"
-        )
+        ingredients = self.soup.find("section", {"id": "ingredienten"}).find_all("li")
         return [normalize_string(ingredient.get_text()) for ingredient in ingredients]
 
     def ingredient_groups(self):
@@ -23,9 +21,9 @@ class UitPaulinesKeukenNL(AbstractScraper):
         )
 
     def instructions(self):
-        instructions = self.soup.find(
-            "div", {"class": "preparation-list"}
-        ).findChildren("p")
+        instructions = self.soup.find("div", {"class": "preparation-list"}).find_all(
+            "p"
+        )
         return "\n".join(
             [normalize_string(instruction.get_text()) for instruction in instructions]
         )
@@ -33,7 +31,7 @@ class UitPaulinesKeukenNL(AbstractScraper):
     def description(self):
         return normalize_string(
             self.soup.find("article", {"class": "single-recipe"})
-            .findChild("section", {"class": "text"})
+            .find("section", {"class": "text"})
             .find_next(name=True)
             .get_text()
         )
