@@ -16,34 +16,15 @@ class WeightWatchersPublic(WeightWatchers):
         _recipe, _delimiter, site_name = title.text.rpartition("|")
         return site_name.lstrip()
 
-    def _find_data_container(self):
-        return self.soup.find("div", {"class": "HorizontalList_list__GESs0"})
-
-    def _extract_item_field(self, item):
-        return item.find("div", {"data-e2e-name": "attribute_item_value"})
-
-    def image(self):
-        return self.soup.find("img", {"class": "FoodMasthead_heroImage__BjVdZ"})["src"]
-
     def language(self):
         return self.soup.find("html").get("xml:lang")
 
     def nutrients(self):
-        return {
-            "points": self.soup.find("div", {"class": "Coin_text__3UOb0"})["aria-label"]
-        }
-
-    def description(self):
-        return normalize_string(
-            self.soup.find("div", {"data-e2e-name": "food_masthead_detail_description"})
-            .find("div", {"class": "ReadMoreLess_collapsed__IAzxP"})
-            .get_text()
-        )
-
-    def instructions(self):
-        return self._get_instructions(
-            "h2", "class", "InstructionsFood_headline__vw7cn", "span"
-        )
+        nutrients = self.schema.nutrients() or {}
+        points = self.soup.find("div", {"class": "Coin_text__3UOb0"})["aria-label"]
+        points = points.replace("&reg;", "")
+        nutrients["points"] = points
+        return nutrients
 
     def _find_ingredient_tags(self):
         return (
